@@ -8,17 +8,13 @@
 #include <vector>
 
 namespace Doar {
-  // keyは'\0'終端文字列で、値が0xFFの文字を含むことはできない
+  // MEMO: keyは'\0'終端文字列で、値が0xFFの文字を含むことはできない
   class KeyStream {
-  public:
-    // TODO: MIN_CODEも入れる?
-    static const unsigned MAX_CODE = 0xFF; // MEMO: キーとして有効な値は、0(終端) ~ MAX_CODE-1
-
   public:
     KeyStream(){}
     KeyStream(const char* key) : cur(key) {}
     
-    Code read() { return static_cast<unsigned char>(*cur++)+1; }
+    Code read() { return static_cast<unsigned char>(*cur++); }
     const char* rest() const { return cur; }
     bool eos() const { return cur[-1]=='\0'; }
 
